@@ -2,6 +2,7 @@
 # general
 ###############################################################################
 
+
 class DALIError(Exception):
     """Base exception for DALI related errors."""
 
@@ -10,6 +11,7 @@ class DALIError(Exception):
 # address
 ###############################################################################
 
+
 class AddressError(DALIError):
     """Base Exception for address related errors."""
 
@@ -22,6 +24,7 @@ class IncompatibleFrame(AddressError):
 # command
 ###############################################################################
 
+
 class CommandError(DALIError):
     """Base Exception for command related errors."""
 
@@ -38,10 +41,12 @@ class ResponseError(CommandError):
 # sequences
 ###############################################################################
 
+
 class DALISequenceError(DALIError):
     """An error occurred during execution of a command sequence."""
     pass
 
+
 class ProgramShortAddressFailure(DALIError):
     """A device did not accept programming of its short address."""
 
@@ -49,17 +54,71 @@ class ProgramShortAddressFailure(DALIError):
         self.address = address
 
 
+###############################################################################
+# memory access
+###############################################################################
+
+
+class MemoryError(DALIError):
+    """Base Exception for memory related errors."""
+    pass
+
+
+class LatchingNotSupported(MemoryError):
+    """This memory bank does not support latching."""
+    pass
+
+
+class MemoryLocationNotImplemented(MemoryError):
+    """The addressed device does not implement the requested memory location."""
+    pass
+
+
+class MemoryWriteError(MemoryError):
+    """Base Exception for memory writing errors."""
+    pass
+
+
+class MemoryValueNotWriteable(MemoryWriteError):
+    """The memory value is not writeable.
+
+    Writing of this memory value is not supported by python-dali.
+    """
+    pass
+
+
+class MemoryLocationNotWriteable(MemoryWriteError):
+    """No response to attempted memory write
+
+    No response was received from the bus unit when attempting to
+    write to a memory location.
+    """
+    pass
+
+
+class MemoryWriteFailure(MemoryWriteError):
+    """Check of DTR0 at end of write yielded unexpected value
+
+    The memory value has not been written correctly. Another attempt
+    to write the value may succeed.
+    """
+    pass
+
+
 ###############################################################################
 # driver
 ###############################################################################
 
+
 class DriverError(DALIError):
     """Base Exception for driver related errors."""
 
+
 class CommunicationError(DriverError):
     """Unable to communicate with the device
     """
 
+
 class UnsupportedFrameTypeError(DriverError):
     """Device driver does not support this type of frame
     """
